From e5e7e850cd55d6b66ea53d66c0220c9c4eea159c Mon Sep 17 00:00:00 2001
From: Andreas Ellewsen <andreas@ellewsen.no>
Date: Mon, 17 Oct 2022 14:38:25 +0200
Subject: [PATCH] Only email sponsor when action is needed

We no longer email sponsors(hosts) if they don't need to verify any of
the information provided by their guest.
---
 gregui/api/views/invitation.py | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/gregui/api/views/invitation.py b/gregui/api/views/invitation.py
index cadd633d..f6e94dc0 100644
--- a/gregui/api/views/invitation.py
+++ b/gregui/api/views/invitation.py
@@ -341,7 +341,8 @@ class InvitedGuestView(GenericAPIView):
             invite_link.expire = timezone.now()
             invite_link.save()
 
-            # Send an email to the sponsor
+        # Send an email to the sponsor if the guest needs to be verified
+        if not person.is_verified:
             confirmmailer = ConfirmGuest()
             confirmmailer.send_confirmation_mail_from_link(invite_link)
         return Response(status=status.HTTP_200_OK)
-- 
GitLab